/*
	Auther		Satoshi Yasuda	7m3tjz/ad6gz
*/

#include <string.h>
#include <errno.h>
#include <stdio.h>
#include <stdarg.h>
#include <usb.h>
#include "dsgwd_pi.h"
#include "node.h"

struct	usb_bus	*bus;
struct	usb_bus	*busses;
struct	usb_device	*dev;
struct  usb_dev_handle *udev = NULL;

void	init_usb(void)
{
	usb_init();
 	usb_find_busses();
	usb_find_devices();
	busses = usb_get_busses();

	for (bus = busses; bus ; bus = bus->next)
	{
		for (dev = bus->devices; dev ; dev = dev->next)
		{
			if ((dev->descriptor.idVendor == VendorID)
				&& (dev->descriptor.idProduct == ProductID))
			{
				logfile = fopen (LOGFILE, "a");
				now = time(NULL);
				fprintf (logfile, "%24.24s Node Adapter found\n", ctime(&now));
				fclose (logfile);
				udev = usb_open(dev);
				return;
			}
		}
	}
	logfile = fopen (LOGFILE, "a");
	now = time(NULL);
	fprintf (logfile, "%24.24s Node Adapter not found\n", ctime(&now));
	fclose (logfile);
	exit(-1);
} 
